@@ -47,6 +47,10 @@ Kwave::FilterPlugin::FilterPlugin(QObject *parent, const QVariantList &args)
 //***************************************************************************
 Kwave::FilterPlugin::~FilterPlugin()
 {
+    if (m_sink) {
+	delete m_sink;
+	m_sink = Q_NULLPTR;
+    }
 }
 
 //***************************************************************************
@@ -102,14 +106,14 @@ void Kwave::FilterPlugin::run(QStringList params)
     // switch to interactive mode in pre-listen mode
     Kwave::StreamObject::setInteractive(m_listen);
 
+    Kwave::SampleSource *filter = createFilter(tracks.count());
+    Q_ASSERT(filter);
+
     // create all objects
     Kwave::MultiTrackReader source(
 	(m_listen) ? Kwave::FullSnapshot : Kwave::SinglePassForward,
 	signalManager(), tracks, first, last);
 
-    Kwave::SampleSource *filter = createFilter(tracks.count());
-    Q_ASSERT(filter);
-
     if (m_listen) {
 	// pre-listen mode
 	Q_ASSERT(m_sink);
@@ -155,8 +159,10 @@ void Kwave::FilterPlugin::run(QStringList params)
     // transport the samples
     while (!shouldStop() && (!source.done() || m_listen)) {
 	// process one step
+	if (m_listen) QThread::yieldCurrentThread();
 	source.goOn();
 	filter->goOn();
+	if (m_listen) QThread::yieldCurrentThread();
 
 	// watch out for changed parameters when in
 	// pre-listen mode
@@ -178,8 +184,10 @@ void Kwave::FilterPlugin::run(QStringList params)
 
     // cleanup
     if (filter)     delete filter;
-    if (m_sink)     delete m_sink;
-    m_sink = Q_NULLPTR;
+    if (!m_listen) {
+	delete m_sink;
+	m_sink = Q_NULLPTR;
+    }
     if (undo_guard) delete undo_guard;
 
     m_pause  = false;
@@ -222,6 +230,8 @@ void Kwave::FilterPlugin::stopPreListen()
     stop();
     m_listen = false;
     setProgressDialogEnabled(true);
+    if (m_sink) delete m_sink;
+    m_sink = Q_NULLPTR;
 }
 
 //***************************************************************************
